use config::WindowConfig;
use state::WindowState;
use winit::event_loop::EventLoop;

use super::app::{App, AppExit};

pub mod config;
pub mod state;

pub fn init(app: &mut App, window_config: WindowConfig) {
    let world = app.world_mut();
    world.insert_resource(window_config);

    let mut event_loop_builder = EventLoop::with_user_event();
    let event_loop = event_loop_builder.build().unwrap();

    app.set_runner(Box::new(move |app| runner(app, event_loop)));
}

fn runner(app: App, event_loop: EventLoop<()>) -> AppExit {
    let mut window_state = WindowState::new(app);

    match event_loop.run_app(&mut window_state) {
        Ok(_) => AppExit::Success,
        Err(e) => AppExit::Error(Box::new(e)),
    }
}
